@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  ninix-update.py - a command-line network update utility for ninix
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2005 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -13,8 +13,6 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-#  $Id: ninix-update.py,v 1.17 2006/08/26 16:01:17 shy Exp $
-#
 
 import getopt
 import os
@@ -92,7 +90,7 @@ def list_ghosts(script):
     ghosts, shells, balloons, plugins, nekoninni, katochan, kinoko = config
     found = 0
     default_path = os.path.join(sys.path[0], 'ninix', 'dll')
-    saori_lib = ninix.dll.Library('saori', default_path, ghost=None)
+    saori_lib = ninix.dll.Library('saori', default_path)
     dll = ninix.dll.Library('shiori', default_path, saori_lib=saori_lib)
     for desc, shiori_dir, use_makoto, surface_set, \
         balloon, prefix, shiori_dll, shiori_name in ghosts:
@@ -153,10 +151,7 @@ def get_value(response):
         else:
             for key in result:
                 result[key] = unicode(result[key], charset, 'ignore')
-    if 'Value' in result:
-        return result['Value']
-    else:
-        return ''
+    return result['Value'] if 'Value' in result else ''
 
 def update_ghost(homeurl, ghostdir, quiet):
     if not os.path.exists(os.path.expanduser(ghostdir)):
