@@ -827,7 +827,7 @@ class BalloonWindow:
         cr.set_source_pixbuf(self.balloon_pixbuf, 0, 0)
         cr.paint_with_alpha(self.__alpha_channel)
 
-    def set_markup(self, index, text):
+    def set_markup(self, index, text): # FIXME: escape & -> &amp;
         tags_ = ('sup', 'sub', 's', 'u')
         count_ = {}
         for tag_ in tags_:
@@ -1295,8 +1295,8 @@ class CommunicateWindow:
     ENTRY = ''
 
     def __init__(self, balloon, sakura, debug):
-        self.__balloon = balloon
-        self.__sakura = sakura
+        self.balloon = balloon
+        self.sakura = sakura
         self.debug = debug
         self.window = None
         self.dragged = 0
@@ -1405,14 +1405,14 @@ class CommunicateBox(CommunicateWindow):
     def delete(self, widget, event):
         self.window.hide()
         self.cancel()
-        self.__balloon.reset_user_interaction()
+        self.balloon.reset_user_interaction()
         return True
 
     def key_press(self, widget, event):
         if event.keyval == gtk.keysyms.Escape:
             self.window.hide()
             self.cancel()
-            self.__balloon.reset_user_interaction()
+            self.balloon.reset_user_interaction()
             return True
         return False
 
@@ -1431,7 +1431,7 @@ class CommunicateBox(CommunicateWindow):
         if data:
             data = unicode(data, 'utf-8')
         if data is not None:
-            self.__sakura.notify_event('OnCommunicate', 'user', data)
+            self.sakura.notify_event('OnCommunicate', 'user', data)
 
 class TeachBox(CommunicateWindow):
 
@@ -1447,8 +1447,8 @@ class TeachBox(CommunicateWindow):
     def send(self, data):
         if data:
             data = unicode(data, 'utf-8')
-        self.__sakura.notify_user_teach(data)
-        self.__balloon.reset_user_interaction()
+        self.sakura.notify_user_teach(data)
+        self.balloon.reset_user_interaction()
 
 class InputBox(CommunicateWindow):
 
@@ -1503,13 +1503,13 @@ class InputBox(CommunicateWindow):
             data = ''
         ## CHECK: symbol
         if self.symbol == 'OnUserInput' and \
-           self.__sakura.notify_event('OnUserInput', data):
+           self.sakura.notify_event('OnUserInput', data):
             pass
-        elif self.__sakura.notify_event('OnUserInput', self.symbol, data):
+        elif self.sakura.notify_event('OnUserInput', self.symbol, data):
             pass
-        elif self.__sakura.notify_event(self.symbol, data):
+        elif self.sakura.notify_event(self.symbol, data):
             pass
-        self.__balloon.reset_user_interaction()
+        self.balloon.reset_user_interaction()
 
 
 def test():
