@@ -1,7 +1,7 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 #
 #  hanayu.py - a "花柚" compatible Saori module for ninix
-#  Copyright (C) 2002-2007 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -11,8 +11,6 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-#  $Id: hanayu.py,v 1.34 2007/04/10 14:45:38 shy Exp $
-#
 
 # TODO:
 # - usetime, line, radar 以外の形式のグラフへの対応.
@@ -22,7 +20,6 @@ import sys
 import os
 import math
 import time
-import gc
 
 if 'DISPLAY' in os.environ:
     if 'gtk' not in sys.modules:
@@ -267,8 +264,9 @@ class Graph:
         self.window.connect('delete_event', self.delete)
         self.window.connect('button_press_event', self.button_press)
         self.window.set_events(gtk.gdk.BUTTON_PRESS_MASK)
-        self.x = gtk.gdk.screen_width() / 2
-        self.y = gtk.gdk.screen_height() / 4
+        left, top, scrn_w, scrn_h = ninix.pix.get_workarea()
+        self.x = left + scrn_w / 2
+        self.y = top + scrn_h / 4
         self.window.move(self.x, self.y)
         self.darea = gtk.DrawingArea()
         self.darea.set_events(gtk.gdk.EXPOSURE_MASK)
@@ -304,7 +302,6 @@ class Graph:
                                             width, height,
                                             gtk.gdk.RGB_DITHER_NONE, 0, 0)
             del pixbuf
-            gc.collect()
         self.darea.window.draw_drawable(self.surface_gc, self.surface_pixmap,
                                         0, 0, 0, 0, self.width, self.height)
 
@@ -359,7 +356,7 @@ class Graph:
         if event.type == gtk.gdk.BUTTON_PRESS:
             self.window.begin_move_drag(
                 event.button, int(event.x_root), int(event.y_root),
-                gtk.get_current_event_time())
+                event.time)
         elif event.type == gtk.gdk._2BUTTON_PRESS: # double click
             self.destroy()
         return True
