@@ -1,9 +1,9 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 #
 #  niseshiori.py - a "偽栞" compatible Shiori module for ninix
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2005 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2003 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -13,8 +13,6 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: niseshiori.py,v 1.25 2005/09/26 04:18:33 shy Exp $
-#
 
 import __builtin__
 import random
@@ -24,12 +22,8 @@ import os
 import re
 import StringIO
 
-try:
-    import _niseshiori
-except ImportError:
-    _niseshiori = None
 
-REVISION = '$Revision: 1.25 $'
+REVISION = '$Revision: 1.28 $'
 
 # tree node types
 ADD_EXPR     = 1
@@ -361,8 +355,6 @@ class NiseShiori:
         return tuple(buf)
 
     def decrypt(self, data):
-        if _niseshiori is not None:
-            return _niseshiori.decrypt(data)
         buf = []
         a = 0x61
         i = 0
@@ -1075,7 +1067,7 @@ class Shiori(NiseShiori):
             'Shiori: NiseShiori compatible module for ninix\n'
             '        Copyright (C) 2001, 2002 by Tamito KAJIYAMA\n'
             '        Copyright (C) 2002, 2003 by MATSUMURA Namihiko\n'
-            '        Copyright (C) 2002-2005 by Shyouzou Sugitani\n'
+            '        Copyright (C) 2002-2009 by Shyouzou Sugitani\n'
             '        Copyright (C) 2003 by Shun-ichi TAHARA\n')
 
     def request(self, req_string):
