@@ -1,7 +1,7 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  wmove.py - a wmove.dll compatible Saori module for ninix
-#  Copyright (C) 2003-2005 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2003-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -30,29 +30,30 @@ else:
     gtk = None
 
 from ninix.dll import SAORI
+import ninix.pix
 
 
 class Saori(SAORI):
 
     def __init__(self):
         SAORI.__init__(self)
-        self.__ghost = None
+        self.__sakura = None
 
-    def need_ghost_backdoor(self, ghost):
-        self.__ghost = ghost
+    def need_ghost_backdoor(self, sakura):
+        self.__sakura = sakura
 
     def load(self, dir=os.curdir):
         self.commands = [[], []]
         self.timeout_id = None
         self.dir = dir
         result = 0
-        if not self.__ghost or not gtk:
+        if not self.__sakura or not gtk:
             pass
         elif self.loaded:
 	    result = 2
         else:
-            self.sakura_name = self.__ghost.get_selfname()
-            self.kero_name = self.__ghost.get_keroname()
+            self.sakura_name = self.__sakura.get_selfname()
+            self.kero_name = self.__sakura.get_keroname()
             self.loaded = 1
             result = 1
 	return result
@@ -128,8 +129,8 @@ class Saori(SAORI):
                     else:
                         return 'SAORI/1.0 400 Bad Request\r\n\r\n'
                     try:
-                        x, y = self.__ghost.get_surface_position(side)
-                        w, h = self.__ghost.get_surface_size(side)
+                        x, y = self.__sakura.get_surface_position(side)
+                        w, h = self.__sakura.get_surface_size(side)
                         return 'SAORI/1.0 200 OK\r\n' \
                                'Result: %d\r\n' \
                                'Value0: %d\r\n' \
@@ -139,8 +140,7 @@ class Saori(SAORI):
                         return 'SAORI/1.0 500 Internal Server Error\r\n\r\n'
                 elif name == 'GET_DESKTOP_SIZE':
 	            try:
-	                scrn_w = gtk.gdk.screen_width()
-	                scrn_h = gtk.gdk.screen_height()
+                        left, top, scrn_w, scrn_h = ninix.pix.get_workarea()
                         return 'SAORI/1.0 200 OK\r\n' \
                                'Result: %d\r\n' \
                                'Value0: %d\r\n' \
@@ -180,58 +180,58 @@ class Saori(SAORI):
             if self.commands[side]:
 	        command, args = self.commands[side].pop(0)
 	        if command in ['MOVE', 'MOVE_INSIDE']:
-                    x, y = self.__ghost.get_surface_position(side)
+                    x, y = self.__sakura.get_surface_position(side)
 	            vx = int(args[0])
 	            speed = int(args[1])
 	            if command == 'MOVE_INSIDE':
-                        w, h = self.__ghost.get_surface_size(side)
-	                scrn_w = gtk.gdk.screen_width()
+                        w, h = self.__sakura.get_surface_size(side)
+                        left, top, scrn_w, scrn_h = ninix.pix.get_workarea()
 	                if vx < 0 and x + vx <0:
 	                    vx = min(-x, 0)
-	                elif vx > 0 and x + vx + w > scrn_w:
-	                    vx = max(scrn_w - w - x, 0)
+	                elif vx > 0 and x + vx + w > left + scrn_w:
+	                    vx = max(left + scrn_w - w - x, 0)
 	            if abs(vx) > speed:
 	                if vx > 0:
-	                    self.__ghost.set_surface_position(
+	                    self.__sakura.set_surface_position(
                                 side, x + speed, y)
 	                    self.commands[side].insert(
                                 0, [command, [str(vx - speed), args[1]]])
 	                elif vx < 0:
-	                    self.__ghost.set_surface_position(
+	                    self.__sakura.set_surface_position(
                                 side, x - speed, y)
 	                    self.commands[side].insert(
                                 0, [command, [str(vx + speed), args[1]]])
 	            else:
-	                self.__ghost.set_surface_position(side, x + vx, y)
+	                self.__sakura.set_surface_position(side, x + vx, y)
 	        elif command in ['MOVETO', 'MOVETO_INSIDE']:
-                    x, y = self.__ghost.get_surface_position(side)
+                    x, y = self.__sakura.get_surface_position(side)
 	            to = int(args[0])
 	            speed = int(args[1])
 	            if command == 'MOVETO_INSIDE':
-                        w, h = self.__ghost.get_surface_size(side)
-	                scrn_w = gtk.gdk.screen_width()
+                        w, h = self.__sakura.get_surface_size(side)
+                        left, top, scrn_w, scrn_h = ninix.pix.get_workarea()
 	                if to < 0:
 	                    to = 0
-	                elif to > scrn_w - w:
-	                    to = scrn_w - w
+	                elif to > left + scrn_w - w:
+	                    to = left + scrn_w - w
 	            if abs(to - x) > speed:
 	                if to - x > 0:
-	                    self.__ghost.set_surface_position(
+	                    self.__sakura.set_surface_position(
                                 side, x + speed, y)
 	                    self.commands[side].insert(0, [command, args])
 	                elif to - x < 0:
-	                    self.__ghost.set_surface_position(
+	                    self.__sakura.set_surface_position(
                                 side, x - speed, y)
 	                    self.commands[side].insert(0, [command, args])
 	            else:
-	                self.__ghost.set_surface_position(side, to, y)
+	                self.__sakura.set_surface_position(side, to, y)
 	        elif command in ['STANDBY', 'STANDBY_INSIDE']:
 	            pass ## FIXME
 	        elif command == 'ZMOVE':
 	            if args[0] == '1':
-	                self.__ghost.raise_surface(side)
+	                self.__sakura.raise_surface(side)
 	            elif args[0] == '2':
-	                self.__ghost.lower_surface(side)
+	                self.__sakura.lower_surface(side)
 	            else:
 	                pass
 	        elif command == 'WAIT':
@@ -244,7 +244,7 @@ class Saori(SAORI):
 	            else:
 	                self.commands[side].insert(0, ['WAIT', str(wait - 20)])
 	        elif command == 'NOTIFY':
-                    self.__ghost.notify_event(*args)
+                    self.__sakura.notify_event(*args)
         if not self.commands[0] and not self.commands[1]:
 	    if self.timeout_id is not None:
                 gobject.source_remove(self.timeout_id)
