@@ -1,8 +1,8 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2006 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -11,8 +11,6 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: home.py,v 1.32 2006/08/26 16:01:18 shy Exp $
-#
 
 import os
 import re
@@ -354,12 +352,13 @@ def find_surface_set(top_dir):
     shell_dir = os.path.join(top_dir, 'shell')
     for name, desc, subdir in find_surface_dir(shell_dir):
         surface_dir = os.path.join(shell_dir, subdir)
-        surface_info, alias = read_surface_info(surface_dir)
+        surface_info, alias, tooltips = read_surface_info(surface_dir)
         if surface_info and \
            'surface0' in surface_info and 'surface10' in surface_info:
             if alias is None:
                 alias = read_alias_txt(surface_dir)
-            surface_set.append((name, surface_dir, desc, alias, surface_info))
+            surface_set.append((name, surface_dir, desc, alias, surface_info,
+                                tooltips))
     return shell_name, surface_set
 
 def find_surface_dir(top_dir):
@@ -425,9 +424,12 @@ def read_surface_info(surface_dir):
         surface[key] = (img, config)
     # find surfaces.txt
     alias = None
+    tooltips = {}
     for key, config in read_surfaces_txt(surface_dir):
         if key == '__alias__':
             alias = config
+        elif key == '__tooltips__':
+            tooltips = config
         elif key.startswith('surface'):
             try:
                 img, null_config = surface[key]
@@ -442,7 +444,7 @@ def read_surface_info(surface_dir):
             if basename not in surface:
                 surface[basename] = (os.path.join(surface_dir, filename),
                                      ninix.config.null_config())
-    return surface, alias
+    return surface, alias, tooltips
 
 def read_surfaces_txt(surface_dir):
     config_list = []
@@ -452,6 +454,8 @@ def read_surfaces_txt(surface_dir):
     except IOError:
         return config_list
     alias_buffer = []
+    tooltips = {}
+    charset = 'Shift_JIS'
     while 1:
         line = f.readline()
         if not line:
@@ -459,6 +463,12 @@ def read_surfaces_txt(surface_dir):
         if line.startswith('#') or line.startswith('//'):
             continue
         key = line.strip()
+        if key.startswith('charset'):
+            try:
+                charset = line.split(',', 1)[1].strip()
+            except:
+                pass
+            continue
         if not key:
             continue
         try:
@@ -488,6 +498,17 @@ def read_surfaces_txt(surface_dir):
                 alias_buffer.append('{')
                 alias_buffer.extend(buf)
                 alias_buffer.append('}')
+            elif key.endswith('.tooltips'):
+                try:
+                    key = key[:-9]
+                except:
+                    pass
+                value = {}
+                for line in buf:
+                    line = line.split(',', 1)
+                    region, text = [unicode(s.strip(), charset, 'ignore') for s in line]
+                    value[region] = text
+                tooltips[key] = value
             elif key.startswith('surface'):
                 try:
                     key = ''.join((key[:7], str(int(key[7:]))))
@@ -499,6 +520,7 @@ def read_surfaces_txt(surface_dir):
             break
     if alias_buffer:
         config_list.append(('__alias__', ninix.alias.new_alias(alias_buffer)))
+    config_list.append(('__tooltips__', tooltips))
     return config_list
 
 def list_surface_elements(config):
