@@ -1,6 +1,6 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2004-2007 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2004-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -16,7 +16,6 @@
 # - 透明度の設定
 
 import os
-import gc
 
 if 'DISPLAY' in os.environ:
     import gtk
@@ -104,7 +103,8 @@ class Kinoko:
     def finalize(self):
         self.__running = 0
         self.target.delete_observer(self)
-        self.skin.destroy()
+        if self.skin is not None:
+            self.skin.destroy()
 
     def notify_observer(self, event, args): ## FIXME
         if self.skin is None:
@@ -112,8 +112,8 @@ class Kinoko:
         if event in ['set position', 'set surface']:
             self.skin.set_position()
             self.skin.show()
-        elif event == 'set scale':
-            scale = self.target.get_surface_scale()
+        elif event == 'set scale': ## FIXME
+            scale = self.target.prefs.get('surface_scale')
             self.skin.set_scale(scale)
         elif event == 'hide':
             if not self.target.surface_is_shown(0):
@@ -141,7 +141,7 @@ class Kinoko:
         self.target = target
         self.target.set_observer(self)
         self.accelgroup = gtk.AccelGroup()
-        scale = self.target.get_surface_scale()
+        scale = self.target.prefs.get('surface_scale')
         self.skin = Skin(self.data, self.accelgroup, self, scale)
         if self.skin is None:
             return 0
@@ -170,8 +170,7 @@ class Kinoko:
         args = (self.data['title'],
                 self.data['ghost'],
                 self.data['category'])
-        sakura = self.target.get_sakura()
-        sakura.notify_event(event, *args)
+        self.target.notify_event(event, *args)
 
     def get_skin_list(self):
         return self.skin_list
@@ -180,7 +179,7 @@ class Kinoko:
         self.send_event('OnKinokoObjectChanging')
         self.skin.destroy()
         self.data = args
-        scale = self.target.get_surface_scale()
+        scale = self.target.prefs.get('surface_scale')
         self.skin = Skin(self.data, self.accelgroup, self, scale)
         if self.skin is None:
             return 0
@@ -195,10 +194,6 @@ class Skin:
         self.data = data
         self.accelgroup = accelgroup
         self.kinoko = kinoko
-        if self.data['ontop']:
-            self.__ontop = 1
-        else:
-            self.__ontop = 0
         self.__menu = Menu(self.kinoko, self.accelgroup)
         self.__scale = scale
         self.__shown = 0
@@ -207,6 +202,7 @@ class Skin:
         ##self.window.set_title(''.join(('surface.', name)))
         self.window.set_decorated(False)
         self.window.set_resizable(False)
+        self.window.set_skip_taskbar_hint(True)
         self.window.connect('delete_event', self.delete)
         self.window.connect('button_press_event', self.button_press)
         self.window.connect('button_release_event', self.button_release)
@@ -233,14 +229,16 @@ class Skin:
         path = os.path.join(self.data['dir'], self.data['base'])
         try:
             self.pixbuf = ninix.pix.create_pixbuf_from_file(path)
-            if self.__scale != 100:
-                w = max(1, self.pixbuf.get_width() * self.__scale / 100)
-                h = max(1, self.pixbuf.get_height() * self.__scale / 100)
+            scale = self.__scale
+            if scale != 100:
+                w = max(1, self.pixbuf.get_width() * scale / 100)
+                h = max(1, self.pixbuf.get_height() * scale / 100)
                 surface_pixbuf = self.pixbuf.scale_simple(
                     w, h, gtk.gdk.INTERP_BILINEAR)
+            else:
+                surface_pixbuf = self.pixbuf.copy()
             image, mask = surface_pixbuf.render_pixmap_and_mask(255)
             del surface_pixbuf
-            gc.collect()
         except: ## FIXME
             self.kinoko.close(None)
             return
@@ -256,14 +254,15 @@ class Skin:
         self.window.add(self.darea)
         self.darea.realize()
         self.darea.window.set_back_pixmap(image, False)
+        target_window = self.kinoko.target.surface.window[0].window # XXX
+        if self.data['ontop']:
+            self.window.set_transient_for(target_window)
+        else:
+            target_window.set_transient_for(self.window)
         self.show()
         self.seriko.reset(self, '') # XXX
         self.seriko.update(self)
         self.seriko.invoke_kinoko(self)
-        if self.data['ontop']:
-            self.window.set_keep_above(True)
-        else:
-            self.window.set_keep_below(True)
 
     def show(self):
         if not self.__shown:
@@ -281,16 +280,17 @@ class Skin:
     def append_actor(self, frame, actor):
         self.seriko.append_actor(frame, actor)
 
-    def set_position(self, xoffset=0, yoffset=0): ## FIXME
+    def set_position(self, xoffset=0, yoffset=0):
         base_x, base_y = self.kinoko.target.get_kinoko_position(
             self.data['baseposition'])
         a, b = [(0.5, 1), (0.5, 0), (0, 0.5), (1, 0.5), (0, 1),
                 (1, 1), (0, 0), (1, 0), (0.5, 0.5)][self.data['baseadjust']]
         offsetx = self.data['offsetx']
         offsety = self.data['offsety']
-        if self.__scale != 100:
-            offsetx = offsetx * self.__scale / 100
-            offsety = offsety * self.__scale / 100
+        scale = self.__scale
+        if scale != 100:
+            offsetx = offsetx * scale / 100
+            offsety = offsety * scale / 100
         self.x = base_x - int(self.w * a) + offsetx + xoffset
         self.y = base_y - int(self.h * b) + offsety + yoffset
         self.window.move(self.x, self.y)
@@ -369,15 +369,15 @@ class Skin:
                 return
         else:
             surface_pixbuf = self.create_surface_pixbuf()
-        if self.__scale != 100:
-            w = max(1, surface_pixbuf.get_width() * self.__scale / 100)
-            h = max(1, surface_pixbuf.get_height() * self.__scale / 100)
+        scale = self.__scale
+        if scale != 100:
+            w = max(1, surface_pixbuf.get_width() * scale / 100)
+            h = max(1, surface_pixbuf.get_height() * scale / 100)
             surface_pixbuf = surface_pixbuf.scale_simple(
                 w, h, gtk.gdk.INTERP_BILINEAR)
         image, mask = surface_pixbuf.render_pixmap_and_mask(255)
         del surface_pixbuf
-        gc.collect()
-        self.w, self.h = self.surface_pixmap.get_size()
+        self.w, self.h = image.get_size()
         self.darea.window.set_back_pixmap(image, False)
         self.window.shape_combine_mask(mask, 0, 0)
         #print 'DRAW:', dir(self.darea)
