@@ -1,6 +1,6 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2003-2007 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2003-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2003 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -13,20 +13,16 @@
 
 import os
 import re
-import gc
 
 if 'DISPLAY' in os.environ:
     import gtk
     import ninix.pix
 
-import ninix.sakura
-import ninix.surface
-
 
 class Menu:
 
-    def __init__(self, ghost, surface):
-        self.__ghost = ghost
+    def __init__(self, sakura, surface):
+        self.__sakura = sakura
         self.__surface = surface
         ui_info = '''
         <ui>
@@ -38,9 +34,7 @@ class Menu:
             <separator/>
             <menu action='Plugin'>
             </menu>
-            <menuitem action='Scaling'/>
             <menuitem action='Stick'/>
-            <menuitem action='Wait'/>
             <separator/>
             <menu action='Options'>
             <menuitem action='Update'/>
@@ -84,34 +78,34 @@ class Menu:
             'Options': [('Options', None, _('Options(_F)'), None),
                      None, 1, 1],
             'Options/Update': [('Update', None, _('Network Update(_U)'), None,
-                             '', lambda *a: self.__ghost.network_update()),
+                             '', lambda *a: self.__sakura.network_update()),
                             None, 1, 1],
             'Options/Vanish': [('Vanish', None, _('Vanish(_F)'), None,
-                             '', lambda *a: self.__ghost.vanish()),
+                             '', lambda *a: self.__sakura.vanish()),
                             None, 1, 1],
             'Options/Reload': [('Reload', None, _('Reload(_L)'), None,
-                             '', lambda *a: self.__ghost.reload()),
+                             '', lambda *a: self.__sakura.reload()),
                             None, 1, 1],
             'Options/Preferences': [('Preferences', None, _('Preferences...(_O)'), None,
-                               '', lambda *a: self.__ghost.edit_preferences()),
+                               '', lambda *a: self.__sakura.prefs.edit_preferences()),
                               None, 1, 1],
             'Options/Manager': [('Manager', None, _('Ghost Manager(_M)'), None,
                               '',
-                              lambda *a: self.__ghost.open_ghost_manager()),
+                              lambda *a: self.__sakura.app.open_ghost_manager()),
                              None, 1, 1],
             'Information': [('Information', None, _('Information(_I)'), None),
                       None, 1, 1],
             'Information/Usage': [('Usage', None, _('Usage graph(_A)'), None,
-                            '', lambda *a: self.__ghost.show_usage()),
+                            '', lambda *a: self.__sakura.app.show_usage()),
                            None, 1, 1],
             'Information/Version': [('Version', None, _('Version(_V)'), None,
-                              '', lambda *a: self.__ghost.about()),
+                              '', lambda *a: self.__sakura.about()),
                              None, 1, 1],
             'Close': [('Close', None, _('Close(_W)'), None,
-                      '', lambda *a: self.__ghost.close()),
+                      '', lambda *a: self.__sakura.close()),
                      None, 1, 1],
             'Quit': [('Quit', None, _('Quit(_Q)'), None,
-                      '', lambda *a: self.__ghost.app.close_all_ghosts()),
+                      '', lambda *a: self.__sakura.get_callback('close all')()),
                      None, 1, 1],
             'Change': [('Change', None, _('Change(_G)'), None),
                        None, 1, 1],
@@ -121,15 +115,11 @@ class Menu:
                       None, 1, 1],
             'Balloon': [('Balloon', None, _('Balloon(_B)'), None),
                         None, 1, 1],
-            'Scaling': [('Scaling', None, _('Surface Scaling(_S)'), None),
-                        None, 1, 1],
             'Costume': [('Costume', None, _('Costume(_C)'), None),
                         None, 1, 1],
             'Stick': [('Stick', None, _('Stick(_Y)'), None,
                        '', self.__surface.window_stick, False),
                       None, 1, 1],
-            'Wait': [('Wait', None, _('Script Wait(_W)'), None),
-                     None, 1, 1],
             'Nekodorif': [('Nekodorif', None, _('Nekodorif(_N)'), None),
                           None, 1, 1],
             'Kinoko': [('Kinoko', None, _('Kinoko(_K)'), None),
@@ -141,10 +131,6 @@ class Menu:
         self.__pixmap_with_sidebar = None
         self.__pixmap_prelight = None
         self.__pixmap_prelight_with_sidebar = None
-        self.__ghost_list = None
-        self.__shell_list = None
-        self.__balloon_list = None
-        self.__plugin_list = None
         self.__fontcolor = {'normal': '#000000', 'prelight': '#ffffff'} ## FIXME
         self.__sidebar_width = 0
         actions = gtk.ActionGroup('Actions')
@@ -158,64 +144,6 @@ class Menu:
         self.ui_manager.insert_action_group(actions, 0)
         self.ui_manager.add_ui_from_string(ui_info)
         self.__popup_menu = self.ui_manager.get_widget('/popup')
-        self.__create_scale_menu()
-        self.__create_speed_menu()
-
-    def __create_scale_menu(self):
-        menu = gtk.Menu()
-        item = gtk.CheckMenuItem(_('Scale Balloon'))
-        if self.__ghost.get_balloon_scalling():
-            item.set_active(True)
-        else:
-            item.set_active(False)
-        item.connect('activate', self.toggle_balloon_scalling)
-        menu.add(item)
-        item.show()
-        item = gtk.SeparatorMenuItem()
-        menu.add(item)
-        item.show()
-        group = None
-        for label, value in ninix.surface.range_scale:
-            item = group = gtk.RadioMenuItem(group, label)
-            item.set_name('popup menu item')
-            item.connect('activate', self.select_surface_scale, value)
-            if value == self.__ghost.get_surface_scale():
-                item.set_active(True)
-            item.show()
-            menu.append(item)
-        menuitem = self.ui_manager.get_widget(''.join(('/popup/', 'Scaling')))
-        menuitem.set_submenu(menu)
-        self.__menu_list['Scaling'][3] = 1 # changed
-
-    def __create_speed_menu(self):
-        menu = gtk.Menu()
-        group = None
-        for label, value in ninix.sakura.range_script_speed:
-            item = group = gtk.RadioMenuItem(group, unicode(label, 'utf-8'))
-            item.set_name('popup menu item')
-            item.connect('activate', self.select_script_speed, value)
-            if value == self.__surface.sakura.get_script_speed(): ## FIXME
-                item.set_active(True)
-            item.show()
-            menu.append(item)
-        menuitem = self.ui_manager.get_widget(''.join(('/popup/', 'Wait')))
-        menuitem.set_submenu(menu)
-        self.__menu_list['Wait'][3] = 1 # changed
-
-    def select_surface_scale(self, widget, value):
-        ##print 'select_surface_scale', value
-        self.__ghost.set_surface_scale(value)
-
-    def select_script_speed(self, widget, value):
-        ##print 'select_script_speed', value
-        self.__surface.sakura.set_script_speed(value) ## FIXME
-
-    def toggle_balloon_scalling(self, widget, value=None):
-        if widget.get_active():
-            balloon_scalling = 1
-        else:
-            balloon_scalling = 0
-        self.__ghost.set_balloon_scalling(balloon_scalling)
 
     def set_fontcolor(self, background, foreground):
         self.__fontcolor['normal'] = '#%02x%02x%02x' % background
@@ -272,7 +200,6 @@ class Menu:
             pixmap, mask = new_pixbuf.render_pixmap_and_mask(255)
             del pixbuf
             del new_pixbuf
-            gc.collect()
         else:
             self.__sidebar_width = 0
         self.__pixmap_with_sidebar = pixmap
@@ -315,7 +242,6 @@ class Menu:
             del pixbuf
             del new_pixbuf
             del pixbuf_sidebar
-            gc.collect()
         self.__pixmap_prelight_with_sidebar = pixmap
 
     def __set_mayuna_menu(self, side):
@@ -394,7 +320,7 @@ class Menu:
                 name_list = self.__ui[key][0][side]
             if name_list: # caption
                 for name in name_list:
-                    caption = self.__ghost.getstring(name)
+                    caption = self.__sakura.getstring(name)
                     if caption:
                         break
                 if caption:
@@ -408,7 +334,7 @@ class Menu:
                 name_list = self.__ui[key][2][side]
             if name_list: # visible
                 for name in name_list:
-                    visible = self.__ghost.getstring(name)
+                    visible = self.__sakura.getstring(name)
                     if visible is not None:
                         break
                 if visible == '0':
@@ -457,11 +383,11 @@ class Menu:
             assert side in [0, 1]
             string = ['sakura', 'kero'][side]
         string = ''.join((string, '.popupmenu.visible'))
-        if self.__ghost.getstring(string) == '0':
+        if self.__sakura.getstring(string) == '0':
             return
         self.__update_ui(side)
         if side == 0:
-            portal = self.__ghost.getstring('sakura.portalsites')
+            portal = self.__sakura.getstring('sakura.portalsites')
         else:
             portal = None
         self.__set_portal_menu(side, portal)
@@ -471,7 +397,7 @@ class Menu:
             assert side in [0, 1]
             string = ['sakura', 'kero'][side]
         string = ''.join((string, '.recommendsites'))
-        recommend = self.__ghost.getstring(string)
+        recommend = self.__sakura.getstring(string)
         self.__set_recommend_menu(side, recommend)
         self.__set_ghost_menu()
         self.__set_shell_menu()
@@ -566,7 +492,7 @@ class Menu:
                         #else:
                         #    bannar = None
                         item = gtk.MenuItem(title)
-                        item.connect('activate', self.__ghost.launch_browser,
+                        item.connect('activate', self.__sakura.notify_site_selection,
                                      (title, url))
                     menu.add(item)
                     item.show()
@@ -600,7 +526,7 @@ class Menu:
                     #else:
                     #    bannar = None
                     item = gtk.MenuItem(title)
-                    item.connect('activate', self.__ghost.launch_browser,
+                    item.connect('activate', self.__sakura.notify_site_selection,
                                  (title, url))
                 menu.add(item)
                 item.show()
@@ -613,7 +539,7 @@ class Menu:
             self.__set_visible('Recommend', 0)
         self.__menu_list['Recommend'][3] = 1 # changed
 
-    def __update_ghost_menu(self, set_list):
+    def __update_ghost_menu(self, set_list, callback, summon):
         ghost_menu = gtk.Menu()
         for i in range(len(set_list)):
             if set_list[i] is None:
@@ -634,8 +560,10 @@ class Menu:
             ghost_menu.append(item)
             if len(shell_list) <= 1:
                 shell_name, value = shell_list[0]
-                item.connect('activate', self.__ghost.app.select_sakura,
-                             (self.__ghost, value)) ## FIXME
+                if summon:
+                    item.connect('activate', callback, value)
+                else:
+                    item.connect('activate', callback, (self.__sakura, value))
                 if set_list[i]['instance'].is_running():
                     item.set_sensitive(False)
             else:
@@ -645,73 +573,35 @@ class Menu:
                 for shell_name, value in shell_list:
                     item = gtk.MenuItem(shell_name)
                     item.set_name('popup menu item')
-                    item.connect('activate', self.__ghost.app.select_sakura,
-                                 (self.__ghost, value)) ## FIXME
+                    if summon:
+                        item.connect('activate', callback, value)
+                    else:
+                        item.connect('activate', callback, (self.__sakura, value))
                     item.show()
                     if set_list[i]['instance'].is_running():
-                        if self.__ghost.current[1] != value[1]:
-                            item.set_sensitive(False)
-                        elif self.__ghost.current[2] == value[2]:
+                        if summon:
                             item.set_sensitive(False)
+                        else:
+                            if self.__sakura.current[1] != value[1]:
+                                item.set_sensitive(False)
+                            elif self.__sakura.current[2] == value[2]:
+                                item.set_sensitive(False)
                     submenu.append(item)
-        menuitem =  self.ui_manager.get_widget(''.join(('/popup/', 'Change')))
+        if summon:
+            path = 'Summon'
+        else:
+            path = 'Change'
+        menuitem = self.ui_manager.get_widget(''.join(('/popup/', path)))
         menuitem.set_submenu(ghost_menu)
-        self.__menu_list['Change'][3] = 1
-        ##self.__ghost_list = set_list
+        self.__menu_list[path][3] = 1
 
     def __set_ghost_menu(self):
-        ghosts = self.__ghost.app.get_ghost_list() ## FIXME
-        if ghosts != self.__ghost_list or self.__ghost_list is None:
-            self.__update_ghost_menu(ghosts)
-            self.__update_summon_menu(ghosts)
+        ghosts = self.__sakura.app.get_ghost_list()
+        self.__update_ghost_menu(ghosts, self.__sakura.app.select_sakura, False)
+        self.__update_ghost_menu(ghosts, self.__sakura.app.start_sakura_cb, True)
 
-    def __update_summon_menu(self, set_list):
-        ghost_menu = gtk.Menu()
-        for i in range(len(set_list)):
-            if set_list[i] is None:
-                continue
-            name = set_list[i]['name']
-            icon = set_list[i]['icon']
-            shell_list = set_list[i]['shell']
-            if icon is not None:
-                image = gtk.Image()
-                image.set_from_pixbuf(icon)
-                image.show()
-                item = gtk.ImageMenuItem(name)
-                item.set_image(image)
-            else:
-                item = gtk.MenuItem(name)
-            item.set_name('popup menu item')
-            item.show()
-            ghost_menu.append(item)
-            if len(shell_list) <= 1:
-                shell_name, value = shell_list[0]
-                item.connect('activate', self.__ghost.app.start_sakura_cb,
-                             value) ## FIXME
-                if set_list[i]['instance'].is_running():
-                    item.set_sensitive(False)
-            else:
-                submenu = gtk.Menu()
-                submenu.set_name('popup menu')
-                item.set_submenu(submenu)
-                for shell_name, value in shell_list:
-                    item = gtk.MenuItem(shell_name)
-                    item.set_name('popup menu item')
-                    item.connect('activate', self.__ghost.app.start_sakura_cb,
-                                 value) ## FIXME
-                    item.show()
-                    if set_list[i]['instance'].is_running():
-                        item.set_sensitive(False)
-                    submenu.append(item)
-        menuitem = self.ui_manager.get_widget(''.join(('/popup/', 'Summon')))
-        menuitem.set_submenu(ghost_menu)
-        self.__menu_list['Summon'][3] = 1
-        ##self.__ghost_list = set_list
-
-    def __update_shell_menu(self, set_list):
-        ##if self.__shell_list is None:
-        ##    self.__create_shell_menu(set_list)
-        ##else:
+    def __set_shell_menu(self):
+        set_list = self.__sakura.app.get_shell_list() ## FIXME
         shell_menu = gtk.Menu()
         for i in range(len(set_list)):
             name = set_list[i]['name']
@@ -722,8 +612,8 @@ class Menu:
             shell_list = set_list[i]['shell']
             if len(shell_list) <= 1:
                 shell_name, value = shell_list[0]
-                item.connect('activate', self.__ghost.app.select_sakura,
-                             (self.__ghost, value)) ## FIXME
+                item.connect('activate', self.__sakura.app.select_sakura,
+                             (self.__sakura, value))
                 ##if working:
                 ##    item.set_sensitive(False)
             else:
@@ -733,8 +623,8 @@ class Menu:
                 for shell_name, value in shell_list:
                     item = gtk.MenuItem(shell_name)
                     item.set_name('popup menu item')
-                    item.connect('activate', self.__ghost.app.select_sakura,
-                                 (self.__ghost, value)) ## FIXME
+                    item.connect('activate', self.__sakura.app.select_sakura,
+                                 (self.__sakura, value))
                     item.show()
                     ##if working: ## FIXME
                     ##    item.set_sensitive(False)
@@ -742,23 +632,16 @@ class Menu:
         menuitem = self.ui_manager.get_widget(''.join(('/popup/', 'Shell')))
         menuitem.set_submenu(shell_menu)
         self.__menu_list['Shell'][3] = 1
-        self.__shell_list = set_list
 
-    def __set_shell_menu(self):
-        shells = self.__ghost.app.get_shell_list() ## FIXME
-        self.__update_shell_menu(shells)
-
-    def __update_balloon_menu(self, balloon_list):
-        ##if self.__balloon_list is None:
-        ##    self.__create_balloon_menu(balloon_list)
-        ##else:
+    def __set_balloon_menu(self):
+        balloon_list = self.__sakura.app.get_balloon_list()
         balloon_menu = gtk.Menu()
         group = None
-        name_own = self.__ghost.get_own_balloon_name()
+        name_own = self.__sakura.get_own_balloon_name()
         if name_own is not None:
             item = group = gtk.RadioMenuItem(group, name_own)
             item.set_name('popup menu item')
-            hid = item.connect('activate', self.__ghost.select_balloon,
+            hid = item.connect('activate', self.__sakura.select_balloon,
                                name_own)
             item.show()
             balloon_menu.append(item)
@@ -769,26 +652,19 @@ class Menu:
             name = balloon_list[i]['name']
             item = group = gtk.RadioMenuItem(group, name)
             item.set_name('popup menu item')
-            hid = item.connect('activate', self.__ghost.select_balloon, name)
+            hid = item.connect('activate', self.__sakura.select_balloon, name)
             item.show()
             balloon_menu.append(item)
-            if name == self.__ghost.get_current_balloon_name():
+            if name == self.__sakura.get_current_balloon_name():
                 item.handler_block(hid)
                 item.activate()
                 item.handler_unblock(hid)
         menuitem = self.ui_manager.get_widget(''.join(('/popup/', 'Balloon')))
         menuitem.set_submenu(balloon_menu)
         self.__menu_list['Balloon'][3] = 1
-        self.__balloon_list = balloon_list
 
-    def __set_balloon_menu(self):
-        balloon_list = self.__ghost.app.get_balloon_list() ## FIXME
-        self.__update_balloon_menu(balloon_list)
-
-    def __update_plugin_menu(self, plugin_list):
-        ##if self.__plugin_list is None:
-        ##    self.__create_plugin_menu(plugin_list)
-        ##else:
+    def __set_plugin_menu(self):
+        plugin_list = self.__sakura.app.get_plugin_list()
         plugin_menu = gtk.Menu()
         for i in range(len(plugin_list)):
             name = plugin_list[i]['name']
@@ -799,7 +675,7 @@ class Menu:
             item_list = plugin_list[i]['items']
             if len(item_list) <= 1:
                 label, value = item_list[0]
-                item.connect('activate', self.__ghost.app.select_plugin, value) ## FIXME
+                item.connect('activate', self.__sakura.app.select_plugin, value)
                 ##if working:
                 ##    item.set_sensitive(False)
             else:
@@ -809,8 +685,8 @@ class Menu:
                 for label, value in item_list:
                     item = gtk.MenuItem(label)
                     item.set_name('popup menu item')
-                    item.connect('activate', self.__ghost.app.select_plugin,
-                                 value) ## FIXME
+                    item.connect('activate', self.__sakura.app.select_plugin,
+                                 value)
                     item.show()
                     ##if working:
                     ##    item.set_sensitive(False)
@@ -818,16 +694,9 @@ class Menu:
         menuitem = self.ui_manager.get_widget(''.join(('/popup/', 'Plugin')))
         menuitem.set_submenu(plugin_menu)
         self.__menu_list['Plugin'][3] = 1
-        self.__plugin_list = plugin_list
 
-    def __set_plugin_menu(self):
-        plugin_list = self.__ghost.app.get_plugin_list() ## FIXME
-        self.__update_plugin_menu(plugin_list)
-
-    def __update_nekodorif_menu(self, nekodorif_list):
-        ##if self.__nekodorif_list is None:
-        ##    self.__create_nekodorif_menu(nekodorif_list)
-        ##else:
+    def __set_nekodorif_menu(self):
+        nekodorif_list = self.__sakura.app.get_nekodorif_list()
         nekodorif_menu = gtk.Menu()
         for i in range(len(nekodorif_list)):
             name = nekodorif_list[i]['name']
@@ -835,24 +704,17 @@ class Menu:
             item.set_name('popup menu item')
             item.show()
             nekodorif_menu.append(item)
-            item.connect('activate', self.__ghost.app.select_nekodorif,
-                         (self.__ghost, nekodorif_list[i]['dir'])) ## FIXME
+            item.connect('activate', self.__sakura.app.select_nekodorif,
+                         (self.__sakura, nekodorif_list[i]['dir']))
             ##if working:
             ##    item.set_sensitive(False)
         menuitem = self.ui_manager.get_widget(
             ''.join(('/popup/', 'Nekodorif')))
         menuitem.set_submenu(nekodorif_menu)
         self.__menu_list['Nekodorif'][3] = 1
-        self.__nekodorif_list = nekodorif_list
 
-    def __set_nekodorif_menu(self):
-        nekodorif_list = self.__ghost.app.get_nekodorif_list() ## FIXME
-        self.__update_nekodorif_menu(nekodorif_list)
-
-    def __update_kinoko_menu(self, kinoko_list):
-        ##if self.__kinoko_list is None:
-        ##    self.__create_kinoko_menu(kinoko_list)
-        ##else:
+    def __set_kinoko_menu(self):
+        kinoko_list = self.__sakura.app.get_kinoko_list()
         kinoko_menu = gtk.Menu()
         for i in range(len(kinoko_list)):
             name = kinoko_list[i]['title']
@@ -860,18 +722,13 @@ class Menu:
             item.set_name('popup menu item')
             item.show()
             kinoko_menu.append(item)
-            item.connect('activate', self.__ghost.app.select_kinoko,
-                         (self.__ghost, kinoko_list[i])) ## FIXME
+            item.connect('activate', self.__sakura.app.select_kinoko,
+                         (self.__sakura, kinoko_list[i]))
             ##if working:
             ##    item.set_sensitive(False)
         menuitem = self.ui_manager.get_widget(''.join(('/popup/', 'Kinoko')))
         menuitem.set_submenu(kinoko_menu)
         self.__menu_list['Kinoko'][3] = 1
-        self.__kinoko_list = kinoko_list
-
-    def __set_kinoko_menu(self):
-        kinoko_list = self.__ghost.app.get_kinoko_list() ## FIXME
-        self.__update_kinoko_menu(kinoko_list)
 
     def get_stick(self):
         item =  self.ui_manager.get_widget(''.join(('/popup/', 'Stick')))
