@@ -15,8 +15,9 @@ import codecs
 import os
 import re
 import sys
-import urllib
 import time
+import urllib
+import webbrowser
 
 from xml.dom import pulldom
 
@@ -534,8 +535,8 @@ class UI:
         button.set_relief(gtk.RELIEF_NONE)
         self.url['HP'] = [None, button.get_child()]
         vbox2.pack_start(button, False, True, 0)
-        button.connect('clicked',
-                       lambda b, w=self: w.launch_browser(self.url['HP'][0]))
+        button.connect(
+            'clicked', lambda b: webbrowser.open(self.url['HP'][0]))
         button.show()
         button = gtk.Button('')
         button.set_relief(gtk.RELIEF_NONE)
@@ -543,8 +544,7 @@ class UI:
         self.url['Public'] = [None, button.get_child()]
         vbox2.pack_start(button, False, True, 0)
         button.connect(
-            'clicked',
-            lambda b, w=self: w.launch_browser(self.url['Public'][0]))
+            'clicked', lambda b: webbrowser.open(self.url['Public'][0]))
         button.show()
         vbox.pack_start(hbox, False, True, 0)
         hbox.show()
@@ -556,13 +556,6 @@ class UI:
         self.info = textview
         return vbox
 
-    def launch_browser(self, url):
-        command = self.ngm.app.prefs.get('browser')
-        if '%s' not in command:
-            sys.stderr.write('cannot execute command (%s missing)\n')
-            return
-        os.system(' '.join((command.replace('%s', url, 1), '&')))
-
     def update_info_area(self):
         info_list = [(_('Author:'), 'Author'),
                      (_('ArchiveTime:'), 'ArchiveTime'),
