@@ -43,7 +43,6 @@ range_script_speed = [(_('None'), -1), # ordinal (-1: no wait)
                       (''.join(('7 (', _('Slow'), ')')), 8)]
 
 # default settings
-DEFAULT_BROWSER = "firefox %s"
 DEFAULT_BALLOON_FONTS = 'Sans'
 
 def get_default_surface_scale():
@@ -110,9 +109,6 @@ def load_prefs():
 
 class PreferenceDialog:
 
-    PREFS_HELPER_PATTERN    = 'helper_%d_pattern'
-    PREFS_HELPER_COMMAND    = 'helper_%d_command'
-
     PREFS_TYPE = {'sakura_name': None,
                   'sakura_surface': int,
                   'default_balloon': None,
@@ -120,9 +116,6 @@ class PreferenceDialog:
                   'script_speed': int,
                   'surface_scale': int,
                   'balloon_scalling': int,
-                  'browser': None,
-                  'helper_%d_pattern': None,
-                  'helper_%d_command': None,
                   'balloon_fonts': None,
                   'allowembryo': int,
                   'check_collision': int,
@@ -146,8 +139,6 @@ class PreferenceDialog:
         self.notebook.show()
         for name, constructor in [
             (_('Font'),            self.make_page_fonts),
-            (_('Browser'),         self.make_page_browser),
-            (_('Helper'),          self.make_page_helper),
             (_('Surface&Balloon'), self.make_page_surface_n_balloon),
             (_('Misc'),            self.make_page_misc),
             (_('Debug'),           self.make_page_debug),
@@ -170,7 +161,6 @@ class PreferenceDialog:
         button.connect('clicked', self.cancel)
         box.add(button)
         button.show()
-        self.rule_editor = RuleEditor(self.window)
 
     def load(self):
         self.__prefs = load_prefs()
@@ -180,15 +170,6 @@ class PreferenceDialog:
         
     def reset(self): ### FIXME ###
         self.set_balloon_fonts(self.get('balloon_fonts', DEFAULT_BALLOON_FONTS))
-        self.set_browser(self.get('browser', DEFAULT_BROWSER))
-        helper_list = []
-        while 1:
-            pattern = self.__prefs.get(self.PREFS_HELPER_PATTERN % len(helper_list)) ## FIXME
-            command = self.__prefs.get(self.PREFS_HELPER_COMMAND % len(helper_list)) ## FIXME
-            if not pattern or not command:
-                break
-            helper_list.append((pattern, command))
-        self.set_helpers(helper_list)
         name = self.get('default_balloon')
         if self.app.find_balloon_by_name(name) is not None:
             self.set_default_balloon(name)
@@ -223,31 +204,12 @@ class PreferenceDialog:
         self.__prefs['sakura_surface'] = self.__saved_prefs['sakura_surface'] = surface
         self.__prefs.save()
 
-    def get_helpers_regex(self):
-        helpers_regex = []
-        for pattern, command in self.get_helpers():
-            try:
-                regex = re.compile(pattern)
-            except re.error:
-                continue
-            helpers_regex.append((regex, command))
-        return helpers_regex
-
     def edit_preferences(self):
         self.show()
 
     def update(self): ## FIXME
         self.__prefs['allowembryo'] = str(1 if self.allowembryo_button.get_active() else 0)
         self.__prefs['balloon_fonts'] = self.fontsel.get_font_name()
-        self.__prefs['browser'] = self.browser.get_text()
-        lstore = self.helpers.get_model()
-        listiter = lstore.get_iter_first()
-        i = 0 ## FIXME
-        while listiter:
-            self.__prefs[self.PREFS_HELPER_PATTERN % i] = lstore.get_value(listiter, 0)
-            self.__prefs[self.PREFS_HELPER_COMMAND % i] = lstore.get_value(listiter, 1)
-            i += 1
-            listiter = lstore.iter_next(listiter)
         name = None
         selected = self.balloon_treeview.get_selection().get_selected()
         if selected:
@@ -307,109 +269,6 @@ class PreferenceDialog:
         page.show()
         return page
 
-    def make_page_browser(self):
-        page = gtk.VBox(spacing=5)
-        page.set_border_width(5)
-        # browser
-        frame = gtk.Frame(unicode(_('Browser'), 'utf-8'))
-        frame.set_size_request(480, -1)
-        page.pack_start(frame)
-        frame.show()
-        box = gtk.VBox(spacing=2)
-        box.set_border_width(5)
-        frame.add(box)
-        box.show()
-        self.browser = gtk.Entry()
-        box.pack_start(self.browser, False)
-        self.browser.show()
-        # help messages
-        frame = gtk.Frame()
-        frame.set_size_request(480, -1)
-        page.pack_start(frame, False)
-        frame.show()
-        box = gtk.VBox(spacing=2)
-        box.set_border_width(5)
-        frame.add(box)
-        box.show()
-        label = gtk.Label(unicode(_('- %s in this command line will be replaced with the URL'), 'utf-8'))
-        label.set_alignment(0, -1)
-        box.pack_start(label, False)
-        label.show()
-        label = gtk.Label(unicode(_('- trailing & is not required.(automagically added)'), 'utf-8'))
-        label.set_alignment(0, -1)
-        box.pack_start(label, False)
-        label.show()
-        page.show()
-        return page
-
-    def make_page_helper(self):
-        page = gtk.VBox(spacing=5)
-        page.set_border_width(5)
-        frame = gtk.Frame(unicode(_('Application'), 'utf-8'))
-        frame.set_size_request(480, -1)
-        page.pack_start(frame)
-        frame.show()
-        box = gtk.VBox(spacing=5)
-        box.set_border_width(5)
-        frame.add(box)
-        box.show()
-        swin = gtk.ScrolledWindow()
-        swin.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        box.pack_start(swin)
-        swin.show()
-        lstore = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
-        self.helpers = gtk.TreeView(lstore)
-        column = gtk.TreeViewColumn('Pattern', gtk.CellRendererText(), text=0)
-        self.helpers.append_column(column)
-        column = gtk.TreeViewColumn('Command', gtk.CellRendererText(), text=1)
-        self.helpers.append_column(column)
-        swin.add(self.helpers)
-        self.helpers.show()
-        bbox = gtk.HButtonBox()
-        bbox.set_spacing(10)
-        bbox.set_layout(gtk.BUTTONBOX_EDGE)
-        bbox.set_border_width(5)
-        box.pack_start(bbox, False)
-        bbox.show()
-        button = gtk.Button('New')
-        button.connect('clicked', self.rule_new)
-        bbox.pack_start(button)
-        button.show()
-        button = gtk.Button('Edit')
-        button.connect('clicked', self.rule_edit)
-        bbox.pack_start(button)
-        button.show()
-        button = gtk.Button('Delete')
-        button.connect('clicked', self.rule_delete)
-        bbox.pack_start(button)
-        button.show()
-        button = gtk.Button('Up')
-        button.connect('clicked', self.rule_up)
-        bbox.pack_start(button)
-        button.show()
-        button = gtk.Button('Down')
-        button.connect('clicked', self.rule_down)
-        bbox.pack_start(button)
-        button.show()
-        frame = gtk.Frame()
-        frame.set_size_request(480, -1)
-        page.pack_start(frame, False)
-        frame.show()
-        box = gtk.VBox(spacing=2)
-        box.set_border_width(5)
-        frame.add(box)
-        box.show()
-        label = gtk.Label(unicode(_('- %s in this command line will be replaced with the filename'), 'utf-8'))
-        label.set_alignment(0, -1)
-        box.pack_start(label, False)
-        label.show()
-        label = gtk.Label(unicode(_('- trailing & is not required.(automagically added)'), 'utf-8'))
-        label.set_alignment(0, -1)
-        box.pack_start(label, False)
-        label.show()
-        page.show()
-        return page
-
     def make_page_surface_n_balloon(self):
         page = gtk.VBox(spacing=5)
         page.set_border_width(5)
@@ -583,58 +442,6 @@ class PreferenceDialog:
         button.show()
         return page
 
-    def rule_new(self, widget):
-        self.rule_editor.set_pattern('')
-        self.rule_editor.set_command('')
-        if self.rule_editor.run('New rule...'):
-            pattern = self.rule_editor.get_pattern()
-            command = self.rule_editor.get_command()
-            lstore = self.helpers.get_model()
-            listiter = lstore.append()
-            lstore.set(listiter, 0, pattern, 1, command)
-
-    def rule_edit(self, widget):
-        selection = self.helpers.get_selection()
-        lstore, listiter = selection.get_selected()
-        if not listiter:
-            return
-        pattern = lstore.get_value(listiter, 0)
-        command = lstore.get_value(listiter, 1)
-        self.rule_editor.set_pattern(pattern)
-        self.rule_editor.set_command(command)
-        if self.rule_editor.run('Edit rule...'):
-            pattern = self.rule_editor.get_pattern()
-            command = self.rule_editor.get_command()
-            lstore.set(listiter, 0, pattern, 1, command)
-
-    def rule_delete(self, widget):
-        selection = self.helpers.get_selection()
-        lstore, listiter = selection.get_selected()
-        if not listiter:
-            return
-        lstore.remove(listiter)
-
-    def rule_up(self, widget):
-        selection = self.helpers.get_selection()
-        lstore, listiter = selection.get_selected()
-        if not listiter:
-            return
-        path = lstore.get_path(listiter)
-        if path[0] == 0:
-            return
-        listiter_ = lstore.get_iter(path[0] - 1)
-        if listiter_:
-            lstore.swap(listiter_, listiter)
-
-    def rule_down(self, widget):
-        selection = self.helpers.get_selection()
-        lstore, listiter = selection.get_selected()
-        if not listiter:
-            return
-        listiter_ = lstore.iter_next(listiter)
-        if listiter_:
-            lstore.swap(listiter_, listiter)
-
     def notify(self): ## FIXME
         for sakura in self.app.get_working_ghost():
             sakura.reset_balloon_fonts() ## FIXME
@@ -656,26 +463,6 @@ class PreferenceDialog:
     def set_balloon_fonts(self, name):
         self.fontsel.set_font_name(name)
 
-    def set_browser(self, command):
-        self.browser.set_text(command)
-
-    def set_helpers(self, helper_list):
-        lstore = self.helpers.get_model()
-        lstore.clear()
-        for pattern, command in helper_list:
-            listiter = lstore.append()
-            lstore.set(listiter, 0, pattern, 1, command)
-
-    def get_helpers(self):
-        helper_list = []
-        while 1:
-            pattern = self.__prefs.get(self.PREFS_HELPER_PATTERN % len(helper_list))
-            command = self.__prefs.get(self.PREFS_HELPER_COMMAND % len(helper_list))
-            if not pattern or not command:
-                break
-            helper_list.append((pattern, command))
-        return helper_list
-
     def set_balloon_scalling(self, flag):
         self.balloon_scalling_button.set_active(True if flag else False)
 
@@ -738,80 +525,3 @@ class PreferenceDialog:
 
     def set_seriko_inactive(self, flag):
         self.seriko_inactive_button.set_active(True if flag else False)
-
-
-class RuleEditor:
-
-    def __init__(self, master=None):
-        self.dialog = gtk.Dialog()
-        self.dialog.connect('delete_event', self.cancel)
-        self.dialog.set_modal(True)
-        self.dialog.set_position(gtk.WIN_POS_CENTER)
-        if master is not None:
-            self.dialog.set_transient_for(master)
-        # entries
-        table = gtk.Table(2, 2)
-        table.set_row_spacings(5)
-        table.set_col_spacings(5)
-        table.set_border_width(10)
-        self.dialog.vbox.pack_start(table)
-        label = gtk.Label('Pattern')
-        table.attach(label, 0, 1, 0, 1, xoptions=gtk.FILL)
-        self.pattern_entry = gtk.Entry()
-        self.pattern_entry.set_size_request(300, -1)
-        self.pattern_entry.connect('changed', self.changed)
-        table.attach(self.pattern_entry, 1, 2, 0, 1)
-        label = gtk.Label('Command')
-        table.attach(label, 0, 1, 1, 2, xoptions=gtk.FILL)
-        self.command_entry = gtk.Entry()
-        self.command_entry.set_size_request(300, -1)
-        self.command_entry.connect('changed', self.changed)
-        table.attach(self.command_entry, 1, 2, 1, 2)
-        self.dialog.vbox.show_all()
-        # buttons
-        self.ok_button = gtk.Button('OK')
-        self.ok_button.connect('clicked', self.ok)
-        self.dialog.action_area.pack_start(self.ok_button)
-        button = gtk.Button('Cancel')
-        button.connect('clicked', self.cancel)
-        self.dialog.action_area.pack_start(button)
-        self.dialog.action_area.show_all()
-
-    def set_pattern(self, text):
-        self.pattern_entry.set_text(text)
-
-    def get_pattern(self):
-        return self.pattern_entry.get_text()
-
-    def set_command(self, text):
-        self.command_entry.set_text(text)
-
-    def get_command(self):
-        return self.command_entry.get_text()
-
-    def changed(self, widget, event=None):
-        if self.pattern_entry.get_text() and \
-           self.command_entry.get_text():
-            self.ok_button.set_sensitive(True)
-        else:
-            self.ok_button.set_sensitive(False)
-
-    def run(self, title):
-        self.dialog.set_title(title)
-        self.dialog.show()
-        gtk.main()
-        return self.done
-
-    def hide(self):
-        self.dialog.hide()
-        gtk.main_quit()
-
-    def ok(self, widget, event=None):
-        self.done = 1
-        self.hide()
-        return True
-
-    def cancel(self, widget, event=None):
-        self.done = 0
-        self.hide()
-        return True
