@@ -13,20 +13,25 @@
 #  PURPOSE.  See the GNU General Public License for more details.
 #
 
+import codecs
 import os
+import random
 import re
-import socket
 import select
+import socket
 import sys
 import time
-import random
-import codecs
+import webbrowser
 import StringIO
 
 if 'DISPLAY' in os.environ:
     import gtk ## FIXME
     import gobject
 
+import pygst
+pygst.require("0.10")
+import gst
+
 import ninix.surface
 import ninix.balloon
 import ninix.dll
@@ -145,6 +150,9 @@ class Sakura:
         name = (shiori_dll, shiori_name)
         self.shiori = self.__dll.request(name)
         self.updateman = ninix.update.NetworkUpdate(self)
+        self.audio_player = gst.element_factory_make("playbin", "player")
+        fakesink = gst.element_factory_make("fakesink", "fakesink")
+        self.audio_player.set_property("video-sink", fakesink)
         char = 2
         while self.desc.get('char%d.seriko.defaultsurface' % char) is not None:
             char += 1
@@ -407,10 +415,6 @@ class Sakura:
     def is_anchor(self, link_id):
         return 1 if len(link_id) == 2 and link_id[0] == 'anchor' else 0
 
-    def launch_browser(self, url): ## FIXME
-        command = self.prefs.get('browser')
-        self.execute_command(command, url)
-
     def execute_command(self, command, arg): ## FIXME
         if '%s' not in command:
             sys.stderr.write('cannot execute command (%s missing)\n')
@@ -606,7 +610,7 @@ class Sakura:
         if self.is_anchor(link_id):
             self.notify_event('OnAnchorSelect', link_id[1])
         elif self.is_URL(link_id):
-            self.launch_browser(link_id)
+            webbrowser.open(link_id)
             self.reset_script(1)
             self.stand_by(0)
         elif self.sstp_entry_db:
@@ -620,7 +624,7 @@ class Sakura:
     def notify_site_selection(self, event, args):
         title, url = args
         if self.is_URL(url):
-            self.launch_browser(url)
+            webbrowser.open(url)
         self.enqueue_event('OnRecommandedSiteChoice', title, url)
 
     def notify_surface_click(self, button, click, side, x, y):
@@ -991,6 +995,7 @@ class Sakura:
         self.hide_all()
         self.surface.finalize()
         self.balloon.finalize()
+        self.audio_player.set_state(gst.STATE_NULL)
 
     def process_script(self):
         now = time.time()
@@ -1386,7 +1391,7 @@ class Sakura:
     def __yen_j(self, args):
         jump_id = args[0]
         if self.is_URL(jump_id):
-            self.launch_browser(jump_id)
+            webbrowser.open(jump_id)
         elif self.sstp_entry_db:
             self.start_script(self.sstp_entry_db.get(jump_id, r'\e'))
 
@@ -1434,10 +1439,9 @@ class Sakura:
         filename = filename.lower()
         path = os.path.join(self.get_prefix(), 'ghost/master', filename)
         if os.path.isfile(path):
-            for regex, command in self.prefs.get_helpers_regex():
-                if regex.search(path):
-                    self.execute_command(command, path)
-                    break
+            self.audio_player.set_state(gst.STATE_NULL)
+            self.audio_player.set_property("uri", "file://" + path)
+            self.audio_player.set_state(gst.STATE_PLAYING)
 
     def __yen_exclamation(self, args): ## FIXME
         if not args:
@@ -1447,7 +1451,7 @@ class Sakura:
         if args[0] == 'raise' and argc >= 2:
             self.notify_event(*args[1:10])
         elif args[0:2] == ['open', 'browser'] and argc > 2:
-            self.launch_browser(args[2])
+            webbrowser.open(args[2])
         elif args[0:2] == ['open', 'communicatebox']:
             if not self.passivemode:
                 self.balloon.open_communicatebox()
