@@ -1,8 +1,8 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  Copyright (C) 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2007 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -11,8 +11,6 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: seriko.py,v 1.27 2007/04/10 14:45:38 shy Exp $
-#
 
 import re
 import sys
@@ -40,6 +38,13 @@ class Controler:
         self.active = []
         self.__move = None
         self.__dirty = 1
+        self.__inactive = False
+
+    def is_active(self):
+        if self.__inactive:
+            return 0
+        else:
+            return 1
 
     def set_base_id(self, window, surface_id):
         if surface_id == -2:
@@ -65,6 +70,10 @@ class Controler:
         if self.timeout_id is not None:
             self.timeout_id = gobject.timeout_add(int(step * 1000.0), self.update, window)
 
+    def set_inactive(self, flag, window):
+        self.__inactive = True if flag else False
+        self.reset(window, window.surface_id)
+
     def update_frame(self, window):
         if self.terminate_flag:
             return False
@@ -99,7 +108,8 @@ class Controler:
     def update(self, window):
         if self.terminate_flag:
             return False
-        window.update()
+        if not self.__inactive:
+            window.update()
         self.timeout_id = gobject.timeout_add(int(self.frame['step'] * 1000), self.update, window)
         return False
 
