@@ -1,8 +1,8 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2005 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -11,8 +11,6 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: update.py,v 1.15 2006/08/26 16:01:18 shy Exp $
-#
 
 import urlparse
 import StringIO
@@ -27,7 +25,7 @@ class NetworkUpdate:
     __BACKUP_SUFFIX = '.BACKUP'
 
     def __init__(self, sakura):
-        self.sakura = sakura
+        self.__sakura = sakura
         self.event_queue = []
         self.state = None
         self.backups = []
@@ -73,8 +71,8 @@ class NetworkUpdate:
 
     def interrupt(self):
         self.event_queue = []
-        if self.sakura:
-            self.sakura.enqueue_event('OnUpdateFailure', 'artificial')
+        if self.__sakura:
+            self.__sakura.enqueue_event('OnUpdateFailure', 'artificial')
         self.state = None
         self.stop(revert=1)
 
@@ -105,7 +103,7 @@ class NetworkUpdate:
         return time.time() - self.timestamp > self.timeout
 
     def run(self):
-        if self.state is None or (self.sakura and self.sakura.event_queue):
+        if self.state is None or (self.__sakura and self.__sakura.event_queue):
             return 0
         elif self.state == 0:
             self.start_updates()
