@@ -10,8 +10,8 @@
 #  PURPOSE.  See the GNU General Public License for more details.
 #
 
-NUMBER = '3.9.9'
-CODENAME = '"I see no more YASAGURE here."'
+NUMBER = '4.0.1'
+CODENAME = 'jump off into never-never land'
 
 VERSION = '%s (%s)' % (NUMBER, CODENAME)
 VERSION_INFO = (''.join((r'\h\s[0]\w8ninix-aya %s\n' % VERSION,
